pub struct ChildStdin {
inner: FileDesc,
}Expand description
A handle to a child process’s standard input (stdin).
This struct is used in the stdin field on Child.
When an instance of ChildStdin is dropped, the ChildStdin’s underlying
file handle will be closed. If the child process was blocked on input prior
to being dropped, it will become unblocked after dropping.
Fields
inner: FileDescTrait Implementations
1.63.0 · Sourceimpl AsFd for ChildStdin
Available on non-Hermit and (Unix) and not ((WebAssembly and non-WASI, or Fortanix and SGX)) only.
impl AsFd for ChildStdin
Available on non-Hermit and (Unix) and not ((WebAssembly and non-WASI, or Fortanix and SGX)) only.
Sourcefn as_fd(&self) -> BorrowedFd<'_>
fn as_fd(&self) -> BorrowedFd<'_>
Available on Unix or Hermit or Trusty or WASI or Motor OS only.
Borrows the file descriptor. Read more
1.2.0 · Sourceimpl AsRawFd for ChildStdin
Available on non-Hermit and (Unix) and not ((WebAssembly and non-WASI, or Fortanix and SGX)) only.
impl AsRawFd for ChildStdin
Available on non-Hermit and (Unix) and not ((WebAssembly and non-WASI, or Fortanix and SGX)) only.
Sourceimpl CopyWrite for ChildStdin
impl CopyWrite for ChildStdin
Sourcefn properties(&self) -> CopyParams
fn properties(&self) -> CopyParams
Extracts the file descriptor and hints/metadata, delegating through wrappers if necessary.
1.16.0 · Sourceimpl Debug for ChildStdin
impl Debug for ChildStdin
1.63.0 · Sourceimpl From<ChildStdin> for OwnedFd
Available on non-Hermit and (Unix) and not ((WebAssembly and non-WASI, or Fortanix and SGX)) only.
impl From<ChildStdin> for OwnedFd
Available on non-Hermit and (Unix) and not ((WebAssembly and non-WASI, or Fortanix and SGX)) only.
Sourcefn from(child_stdin: ChildStdin) -> OwnedFd
fn from(child_stdin: ChildStdin) -> OwnedFd
Takes ownership of a ChildStdin’s file descriptor.
1.20.0 · Sourceimpl From<ChildStdin> for Stdio
impl From<ChildStdin> for Stdio
Sourcefn from(child: ChildStdin) -> Stdio
fn from(child: ChildStdin) -> Stdio
Converts a ChildStdin into a Stdio.
Examples
ChildStdin will be converted to Stdio using Stdio::from under the hood.
use std::process::{Command, Stdio};
let reverse = Command::new("rev")
.stdin(Stdio::piped())
.spawn()
.expect("failed reverse command");
let _echo = Command::new("echo")
.arg("Hello, world!")
.stdout(reverse.stdin.unwrap()) // Converted into a Stdio here
.output()
.expect("failed echo command");
// "!dlrow ,olleH" echoed to console1.74.0 · Sourceimpl From<OwnedFd> for ChildStdin
Available on non-Hermit and (Unix) and not ((WebAssembly and non-WASI, or Fortanix and SGX)) only.Creates a ChildStdin from the provided OwnedFd.
impl From<OwnedFd> for ChildStdin
Available on non-Hermit and (Unix) and not ((WebAssembly and non-WASI, or Fortanix and SGX)) only.
Creates a ChildStdin from the provided OwnedFd.
The provided file descriptor must point to a pipe
with the CLOEXEC flag set.
Sourceimpl FromInner<FileDesc> for ChildStdin
impl FromInner<FileDesc> for ChildStdin
fn from_inner(pipe: FileDesc) -> ChildStdin ⓘ
Sourceimpl IntoInner<FileDesc> for ChildStdin
impl IntoInner<FileDesc> for ChildStdin
fn into_inner(self) -> FileDesc ⓘ
1.4.0 · Sourceimpl IntoRawFd for ChildStdin
Available on non-Hermit and (Unix) and not ((WebAssembly and non-WASI, or Fortanix and SGX)) only.
impl IntoRawFd for ChildStdin
Available on non-Hermit and (Unix) and not ((WebAssembly and non-WASI, or Fortanix and SGX)) only.
Sourcefn into_raw_fd(self) -> RawFd
fn into_raw_fd(self) -> RawFd
Available on Unix or Hermit or Trusty or WASI or Motor OS only.
Consumes this object, returning the raw underlying file descriptor. Read more
1.48.0 · Sourceimpl Write for &ChildStdin
impl Write for &ChildStdin
Sourcefn write(&mut self, buf: &[u8]) -> Result<usize>
fn write(&mut self, buf: &[u8]) -> Result<usize>
Writes a buffer into this writer, returning how many bytes were written. Read more
Sourcefn is_write_vectored(&self) -> bool
fn is_write_vectored(&self) -> bool
🔬This is a nightly-only experimental API. (
can_vector #69941)Sourcefn flush(&mut self) -> Result<()>
fn flush(&mut self) -> Result<()>
Flushes this output stream, ensuring that all intermediately buffered
contents reach their destination. Read more
1.0.0 · Sourcefn write_all(&mut self, buf: &[u8]) -> Result<()>
fn write_all(&mut self, buf: &[u8]) -> Result<()>
Attempts to write an entire buffer into this writer. Read more
Sourcefn write_all_vectored(&mut self, bufs: &mut [IoSlice<'_>]) -> Result<()>
fn write_all_vectored(&mut self, bufs: &mut [IoSlice<'_>]) -> Result<()>
🔬This is a nightly-only experimental API. (
write_all_vectored #70436)Attempts to write multiple buffers into this writer. Read more
1.0.0 · Sourceimpl Write for ChildStdin
impl Write for ChildStdin
Sourcefn write(&mut self, buf: &[u8]) -> Result<usize>
fn write(&mut self, buf: &[u8]) -> Result<usize>
Writes a buffer into this writer, returning how many bytes were written. Read more
Sourcefn is_write_vectored(&self) -> bool
fn is_write_vectored(&self) -> bool
🔬This is a nightly-only experimental API. (
can_vector #69941)Sourcefn flush(&mut self) -> Result<()>
fn flush(&mut self) -> Result<()>
Flushes this output stream, ensuring that all intermediately buffered
contents reach their destination. Read more
1.0.0 · Sourcefn write_all(&mut self, buf: &[u8]) -> Result<()>
fn write_all(&mut self, buf: &[u8]) -> Result<()>
Attempts to write an entire buffer into this writer. Read more
Sourcefn write_all_vectored(&mut self, bufs: &mut [IoSlice<'_>]) -> Result<()>
fn write_all_vectored(&mut self, bufs: &mut [IoSlice<'_>]) -> Result<()>
🔬This is a nightly-only experimental API. (
write_all_vectored #70436)Attempts to write multiple buffers into this writer. Read more