pub struct ChildStderr {
inner: FileDesc,
}Expand description
Fields
inner: FileDescTrait Implementations
1.63.0 · Sourceimpl AsFd for ChildStderr
Available on non-Hermit and (Unix) and not ((WebAssembly and non-WASI, or Fortanix and SGX)) only.
impl AsFd for ChildStderr
Available on non-Hermit and (Unix) and not ((WebAssembly and non-WASI, or Fortanix and SGX)) only.
Sourcefn as_fd(&self) -> BorrowedFd<'_>
fn as_fd(&self) -> BorrowedFd<'_>
Available on Unix or Hermit or Trusty or WASI or Motor OS only.
Borrows the file descriptor. Read more
1.2.0 · Sourceimpl AsRawFd for ChildStderr
Available on non-Hermit and (Unix) and not ((WebAssembly and non-WASI, or Fortanix and SGX)) only.
impl AsRawFd for ChildStderr
Available on non-Hermit and (Unix) and not ((WebAssembly and non-WASI, or Fortanix and SGX)) only.
Sourceimpl CopyRead for ChildStderr
impl CopyRead for ChildStderr
Sourcefn properties(&self) -> CopyParams
fn properties(&self) -> CopyParams
Extracts the file descriptor and hints/metadata, delegating through wrappers if necessary.
Sourcefn drain_to<W: Write>(&mut self, _writer: &mut W, _limit: u64) -> Result<u64>
fn drain_to<W: Write>(&mut self, _writer: &mut W, _limit: u64) -> Result<u64>
Implementations that contain buffers (i.e.
BufReader) must transfer data from their internal
buffers into writer until either the buffers are emptied or limit bytes have been
transferred, whichever occurs sooner.
If nested buffers are present the outer buffers must be drained first. Read more1.16.0 · Sourceimpl Debug for ChildStderr
impl Debug for ChildStderr
1.63.0 · Sourceimpl From<ChildStderr> for OwnedFd
Available on non-Hermit and (Unix) and not ((WebAssembly and non-WASI, or Fortanix and SGX)) only.
impl From<ChildStderr> for OwnedFd
Available on non-Hermit and (Unix) and not ((WebAssembly and non-WASI, or Fortanix and SGX)) only.
Sourcefn from(child_stderr: ChildStderr) -> OwnedFd
fn from(child_stderr: ChildStderr) -> OwnedFd
Takes ownership of a ChildStderr’s file descriptor.
1.20.0 · Sourceimpl From<ChildStderr> for Stdio
impl From<ChildStderr> for Stdio
Sourcefn from(child: ChildStderr) -> Stdio
fn from(child: ChildStderr) -> Stdio
Converts a ChildStderr into a Stdio.
Examples
use std::process::{Command, Stdio};
let reverse = Command::new("rev")
.arg("non_existing_file.txt")
.stderr(Stdio::piped())
.spawn()
.expect("failed reverse command");
let cat = Command::new("cat")
.arg("-")
.stdin(reverse.stderr.unwrap()) // Converted into a Stdio here
.output()
.expect("failed echo command");
assert_eq!(
String::from_utf8_lossy(&cat.stdout),
"rev: cannot open non_existing_file.txt: No such file or directory\n"
);1.74.0 · Sourceimpl From<OwnedFd> for ChildStderr
Available on non-Hermit and (Unix) and not ((WebAssembly and non-WASI, or Fortanix and SGX)) only.Creates a ChildStderr from the provided OwnedFd.
impl From<OwnedFd> for ChildStderr
Available on non-Hermit and (Unix) and not ((WebAssembly and non-WASI, or Fortanix and SGX)) only.
Creates a ChildStderr from the provided OwnedFd.
The provided file descriptor must point to a pipe
with the CLOEXEC flag set.
Sourceimpl FromInner<FileDesc> for ChildStderr
impl FromInner<FileDesc> for ChildStderr
fn from_inner(pipe: FileDesc) -> ChildStderr ⓘ
Sourceimpl IntoInner<FileDesc> for ChildStderr
impl IntoInner<FileDesc> for ChildStderr
fn into_inner(self) -> FileDesc ⓘ
1.4.0 · Sourceimpl IntoRawFd for ChildStderr
Available on non-Hermit and (Unix) and not ((WebAssembly and non-WASI, or Fortanix and SGX)) only.
impl IntoRawFd for ChildStderr
Available on non-Hermit and (Unix) and not ((WebAssembly and non-WASI, or Fortanix and SGX)) only.
Sourcefn into_raw_fd(self) -> RawFd
fn into_raw_fd(self) -> RawFd
Available on Unix or Hermit or Trusty or WASI or Motor OS only.
Consumes this object, returning the raw underlying file descriptor. Read more
1.0.0 · Sourceimpl Read for ChildStderr
impl Read for ChildStderr
Sourcefn read(&mut self, buf: &mut [u8]) -> Result<usize>
fn read(&mut self, buf: &mut [u8]) -> Result<usize>
Pull some bytes from this source into the specified buffer, returning
how many bytes were read. Read more
Sourcefn read_buf(&mut self, buf: BorrowedCursor<'_>) -> Result<()>
fn read_buf(&mut self, buf: BorrowedCursor<'_>) -> Result<()>
🔬This is a nightly-only experimental API. (
read_buf #78485)Pull some bytes from this source into the specified buffer. Read more
Sourcefn read_vectored(&mut self, bufs: &mut [IoSliceMut<'_>]) -> Result<usize>
fn read_vectored(&mut self, bufs: &mut [IoSliceMut<'_>]) -> Result<usize>
Like
read, except that it reads into a slice of buffers. Read moreSourcefn is_read_vectored(&self) -> bool
fn is_read_vectored(&self) -> bool
🔬This is a nightly-only experimental API. (
can_vector #69941)Sourcefn read_to_end(&mut self, buf: &mut Vec<u8>) -> Result<usize>
fn read_to_end(&mut self, buf: &mut Vec<u8>) -> Result<usize>
Reads all bytes until EOF in this source, placing them into
buf. Read more1.0.0 · Sourcefn read_to_string(&mut self, buf: &mut String) -> Result<usize>
fn read_to_string(&mut self, buf: &mut String) -> Result<usize>
Reads all bytes until EOF in this source, appending them to
buf. Read more1.6.0 · Sourcefn read_exact(&mut self, buf: &mut [u8]) -> Result<()>
fn read_exact(&mut self, buf: &mut [u8]) -> Result<()>
Reads the exact number of bytes required to fill
buf. Read moreSourcefn read_buf_exact(&mut self, cursor: BorrowedCursor<'_>) -> Result<()>
fn read_buf_exact(&mut self, cursor: BorrowedCursor<'_>) -> Result<()>
🔬This is a nightly-only experimental API. (
read_buf #78485)Reads the exact number of bytes required to fill
cursor. Read more1.0.0 · Sourcefn by_ref(&mut self) -> &mut Selfwhere
Self: Sized,
fn by_ref(&mut self) -> &mut Selfwhere
Self: Sized,
Creates a “by reference” adapter for this instance of
Read. Read more1.0.0 · Sourcefn chain<R: Read>(self, next: R) -> Chain<Self, R> ⓘwhere
Self: Sized,
fn chain<R: Read>(self, next: R) -> Chain<Self, R> ⓘwhere
Self: Sized,
Creates an adapter which will chain this stream with another. Read more